@@ -1,23 +1,17 @@
 from __future__ import absolute_import, print_function
 
-from .config import tape
+import unittest
+from unittest.case import skip
 
+from mock import MagicMock, patch
 import six
-if six.PY3:
-    import unittest
-    from unittest.case import skip
-else:
-    import unittest2 as unittest
-    from unittest2.case import skip
-
-from tweepy.api import API
-from tweepy.auth import OAuthHandler
-from tweepy.models import Status
-from tweepy.streaming import Stream, StreamListener, ReadBuffer
 
 from .config import create_auth
 from .test_utils import mock_tweet
-from mock import MagicMock, patch
+from tweepy.api import API
+from tweepy.auth import OAuthHandler
+from tweepy.models import Status
+from tweepy.streaming import ReadBuffer, Stream, StreamListener
 
 
 if six.PY3:
@@ -93,19 +87,19 @@ class TweepyStreamTests(unittest.TestCase):
     def test_sample(self):
         self.listener.status_stop_count = 10
         self.stream.sample()
-        self.assertEquals(self.listener.status_count,
-                          self.listener.status_stop_count)
+        self.assertEqual(self.listener.status_count,
+                         self.listener.status_stop_count)
 
     def test_filter_track(self):
         self.listener.status_stop_count = 5
         phrases = ['twitter']
         self.stream.filter(track=phrases)
-        self.assertEquals(self.listener.status_count,
-                          self.listener.status_stop_count)
+        self.assertEqual(self.listener.status_count,
+                         self.listener.status_stop_count)
 
     def test_track_encoding(self):
         s = Stream(None, None)
-        s._start = lambda async: None
+        s._start = lambda is_async: None
         s.filter(track=[u'Caf\xe9'])
 
         # Should be UTF-8 encoded
@@ -113,7 +107,7 @@ class TweepyStreamTests(unittest.TestCase):
 
     def test_follow_encoding(self):
         s = Stream(None, None)
-        s._start = lambda async: None
+        s._start = lambda is_async: None
         s.filter(follow=[u'Caf\xe9'])
 
         # Should be UTF-8 encoded
