@@ -1,13 +1,9 @@
-import six
-if six.PY3:
-    import unittest
-else:
-    import unittest2 as unittest
+import random
+import string
+import unittest
 
 from tweepy.utils import *
 
-import random
-import string
 
 def mock_tweet():
     """Generate some random tweet text."""
